from setuptools import setup, find_packages

setup(
    name="geometri-package",
    version="0.1.1",
    packages=find_packages(),
    long_description=open("README.md").read(),
    long_description_content_type='text/markdown',  
    description="Paket untuk menghitung berbagai bangun ruang.",
    author="Kelompok 4 ALGO A",
    author_email="office@unhas.ac.id",
    url="https://github.com/nurulmarisa8/geometri-package.git",
    license="MIT",
)
